local gtt = GameTooltip;

-- Variables
local ttm = CreateFrame("Frame","TipTacMSP");
local current = {};

-- ACE Einbinden
local L = LibStub("AceLocale-3.0"):GetLocale("TipTacMSP", true)
local AceConfig = LibStub("AceConfig-3.0")
local AceConfigDialog = LibStub("AceConfigDialog-3.0")


-- Allow these to be accessed externally from other addons
ttm.current = current;

ttm:Hide();

-- Constants, need to be seperated in a extra file.
local rolePlayStyle = {
	["0"] = { code = "0", text = L["undefined"]},
	["1"] = { code = "1", text = L["Normal"]},
	["2"] = { code = "2", text = L["Casual"]},
	["3"] = { code = "3", text = L["Full-Time"]},
	["4"] = { code = "4", text = L["Beginner"]}
}

local rolePlayStatus = {
	["0"] = { code = "0", text = L["undefined"]},
	["1"] = { code = "0", text = L["out of Character"]},
	["2"] = { code = "0", text = L["in Character"]},
	["3"] = { code = "0", text = L["Looking For Contact"]},
	["4"] = { code = "0", text = L["Storyteller"]}
}

local options = {
	type = "group",
	args = {
		core = {
			type = "group",
			name = "General",
			order = 1,
			args = {
				testToggle = {
					type = "header",
					name = "TipTac",
				},
			}
		},
		MSP = {
			type = "group",
			name = "MSP",
			order = 100,
			args = {
				showMSPName = { 
					type = "toggle", 
					order = 1,
					name = L["Show MSP Name"], 
					desc = L["Shows the MSP Name in the Game Tooltip."],
					get = function() return TipTac_Config.showMSPName end,
					set = function(info, v)	TipTac_Config.showMSPName = v end,
					disabled = function() return false end,
					width = "full"
				},
				showMSPState = { 
					type = "toggle", 
					order = 2,
					name = L["Show MSP Status"], 
					desc = L["Shows the MSP Status in the Game Tooltip."],
					get = function() return TipTac_Config.showMSPState end,
					set = function(info, v)	TipTac_Config.showMSPState = v end,
					disabled = function() return false end,
					width = "full"
				},
				showMSPStyle = { 
					type = "toggle", 
					order = 3,
					name = L["Show MSP RP Style"], 
					desc = L["Shows the MSP Roleplay Style in the Game Tooltip."],
					get = function() return TipTac_Config.showMSPStyle end,
					set = function(info, v)	TipTac_Config.showMSPStyle = v end,
					disabled = function() return false end,
					width = "full"
				},
				showMSPClient = { 
					type = "toggle", 
					order = 4,
					name = L["Show MSP Client"], 
					desc = L["Shows the MSP Client(s) in the Game Tooltip."],
					get = function() return TipTac_Config.showMSPClient end,
					set = function(info, v)	TipTac_Config.showMSPClient = v end,
					disabled = function() return false end,
					width = "full"
				}
			}
		}
	}
}
ttm.options = options

local mainAddon = "TipTac";

--------------------------------------------------------------------------------------------------------
--                                           Gather MSP
--------------------------------------------------------------------------------------------------------

local function GatherMSP(field)
	if _G.msp ~= nil then
		playername = current.name;
		_G.msp.Request(playername, field);
		if (_G.msp.char[playername] ~= nil) then
			if (_G.msp.char[playername].field[field] ~= "") then
				return _G.msp.char[playername].field[field]
			end
		end
		return nil
	else
		return "No MSP-Compatible Addon found"
	end
end

function ttm:TipTacMSPFindConfigWindowAndAddOwnConfig()
	-- "Workaround" to add the Options to the TipTac-Options-Menu
	TipTacOptions.options[2][#TipTacOptions.options[2] + 1] =
		{ type = "Check", var = "showMSPName", label = L["Show MSP Name"], tip = L["Shows the MSP Name in the Game Tooltip."]};
	TipTacOptions.options[2][#TipTacOptions.options[2] + 1] =
		{ type = "Check", var = "showMSPState", label = L["Show MSP Status"], tip = L["Shows the MSP Status in the Game Tooltip."]};
	TipTacOptions.options[2][#TipTacOptions.options[2] + 1] =
		{ type = "Check", var = "showMSPStyle", label = L["Show MSP RP Style"], tip = L["Shows the MSP Roleplay Style in the Game Tooltip."]};
	TipTacOptions.options[2][#TipTacOptions.options[2] + 1] =
		{ type = "Check", var = "showMSPClient", label = L["Show MSP Client"], tip = L["Shows the MSP Client(s) in the Game Tooltip."]};
	
	-- Set Defaults in this "Workaround"
	if (TipTac_Config.showMSPState == nil) then
		print("TipTacMSP-Status Settings set to Default. To change, go to the TipTac-Options to the 'Special' page.");
		TipTac_Config.showMSPState = true;
	end
	if (TipTac_Config.showMSPName == nil) then
		print("TipTacMSP-Name Settings set to Default. To change, go to the TipTac-Options to the 'Special' page.");
		TipTac_Config.showMSPName = true;
	end
	if (TipTac_Config.showMSPClient == nil) then
		print("TipTacMSP-Client Settings set to Default. To change, go to the TipTac-Options to the 'Special' page.");
		TipTac_Config.showMSPClient = false;
	end
	if (TipTac_Config.showMSPStyle == nil) then
		print("TipTacMSP-RP-Style Settings set to Default. To change, go to the TipTac-Options to the 'Special' page.");
		TipTac_Config.showMSPStyle = false;
	end
	
	-- Register Main page.
	AceConfigDialog:AddToBlizOptions(mainAddon, mainAddon, nil, "core");
	--AceConfigDialog:AddToBlizOptions(mainAddon, "General", mainAddon, "core");
	AceConfigDialog:AddToBlizOptions(mainAddon, "MSP", mainAddon, "MSP");
	AceConfig:RegisterOptionsTable(mainAddon, options);
end

gtt:HookScript("OnTooltipSetUnit",function(self,...)
	-- Get the unit -- Check the UnitFrame unit if this tip is from a concated unit, such as "targettarget".
	local _, unit = self:GetUnit();
	if (not unit) then
		local mFocus = GetMouseFocus();
		if (mFocus) and (mFocus.unit) then
			unit = mFocus.unit;
		end
	end
	
	-- No Unit or not a Player
	if (not unit) or (not UnitIsPlayer(unit)) then
		return;
	end
	
	-- Wipe Current Record
	wipe(current);
	current.unit = unit;
	current.name = UnitName(unit);
	current.guid = UnitGUID(unit);
	
	if (TipTac_Config.showMSPName) then
		current.msp_na = GatherMSP("NA");
		if ((current.msp_na ~= nil) and (current.msp_na ~= current.name)) then
			self:AddLine(L["MSP-Name"]..": "..current.msp_na);
		end
	end
	if (TipTac_Config.showMSPState) then
		current.msp_fc = GatherMSP("FC");
		if (current.msp_fc ~= nil) then
			if (rolePlayStatus[current.msp_fc] ~= nil) then
				self:AddLine(L["MSP-Status"]..": "..rolePlayStatus[current.msp_fc].text);
			else
				self:AddLine(L["MSP-Status"]..": "..current.msp_fc);
			end
			
		end
	end
	if (TipTac_Config.showMSPStyle) then
		current.msp_fr = GatherMSP("FR");
		if (current.msp_fr ~= nil) then
			if (rolePlayStyle[current.msp_fr] ~= nil) then
				self:AddLine(L["MSP-Style"]..": "..rolePlayStyle[current.msp_fr].text);
			else
				self:AddLine(L["MSP-Style"]..": "..current.msp_fr);
			end
		end
	end
	if (TipTac_Config.showMSPClient) then
		current.msp_va = GatherMSP("VA");
		if (current.msp_va ~= nil) then
			self:AddLine(L["MSP-Client"]..": "..current.msp_va);
		end
	end
end);

ttm:TipTacMSPFindConfigWindowAndAddOwnConfig();